## monday_lib

monday_lib is a complete wrapper for all Monday.com API endpoints. Making the API a little less difficult to retrieve or create data from.

## Features

- Connect to the Monday API  endpoints
- Query data from Monday
- Create data in Monday
- Get all querys in a nicely extracted list
- Get the raw response from endpoints that create data

## Used Modules

monday_lib uses other modules to function properly.

- [requests] - To connect to the API

## Installation

To install monday_lib type: "python -m pip install monday_lib" in a command prompt, or terminal.


## License

GNU GPLv3


[//]: # (These are reference links used in the body of this note and get stripped out when the markdown processor does its job. There is no need to format nicely because it shouldn't be seen. Thanks SO - http://stackoverflow.com/questions/4823468/store-comments-in-markdown-syntax)

   [requests]: <https://github.com/psf/requests>
